[mpich-commits] [mpich] MPICH primary repository branch, master, updated. v3.2b2-46-g443f495

Service Account noreply at mpich.org
Tue May 26 21:37:15 CDT 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "MPICH primary repository".

The branch, master has been updated
       via  443f495c1fe5eac127633dbc1805a47f4e48d849 (commit)
      from  65945a437838d8716da01ea12a9c58e664ee8bf8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.mpich.org/mpich.git/commitdiff/443f495c1fe5eac127633dbc1805a47f4e48d849

commit 443f495c1fe5eac127633dbc1805a47f4e48d849
Author: Ken Raffenetti <raffenet at mcs.anl.gov>
Date:   Tue May 26 14:25:28 2015 -0500

    netmod/portals4: free allocated memory in cancel send
    
    Frees memory allocated to track large sends when those sends are
    successfully cancelled.
    
    No reviewer.

diff --git a/src/mpid/ch3/channels/nemesis/netmod/portals4/ptl_probe.c b/src/mpid/ch3/channels/nemesis/netmod/portals4/ptl_probe.c
index be03923..d04ba04 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/portals4/ptl_probe.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/portals4/ptl_probe.c
@@ -385,12 +385,15 @@ int MPID_nem_ptl_pkt_cancel_send_resp_handler(MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *p
     if (resp_pkt->ack) {
         MPIR_STATUS_SET_CANCEL_BIT(sreq->status, TRUE);
 
         /* remove any remaining get MEs */
         for (i = 0; i < REQ_PTL(sreq)->num_gets; i++) {
             ret = PtlMEUnlink(REQ_PTL(sreq)->get_me_p[i]);
             MPIU_ERR_CHKANDJUMP1(ret, mpi_errno, MPI_ERR_OTHER, "**ptlmeunlink", "**ptlmeunlink %s", MPID_nem_ptl_strerror(ret));
             MPIDI_CH3U_Request_complete(sreq);
         }
+        if (REQ_PTL(sreq)->get_me_p)
+            MPIU_Free(REQ_PTL(sreq)->get_me_p);
+
         MPIU_DBG_MSG(CH3_OTHER,TYPICAL,"message cancelled");
     } else {
         MPIR_STATUS_SET_CANCEL_BIT(sreq->status, FALSE);

-----------------------------------------------------------------------

Summary of changes:
 .../channels/nemesis/netmod/portals4/ptl_probe.c   |    5 ++++-
@@ -385,12 +385,15 @@ int MPID_nem_ptl_pkt_cancel_send_resp_handler(MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *p
         MPIR_STATUS_SET_CANCEL_BIT(sreq->status, TRUE);
 
-        /* remove any remaining get MEs */
+        /* remove/free any remaining get MEs and handles */
         for (i = 0; i < REQ_PTL(sreq)->num_gets; i++) {
             ret = PtlMEUnlink(REQ_PTL(sreq)->get_me_p[i]);
 1 files changed, 4 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
MPICH primary repository


More information about the commits mailing list